AiiDA Phonopy plugin
====================

This a phonopy plugin for AiiDA. This plugin includes workflows to
calculate phonons with supercell and finite displacement approaches.
Currently it provides interfaces only to VASP.
